@@ -249,6 +249,7 @@ def clone(snapshot_id, clone_name, new_size=0):
     lvol.top_bdev = f"{lvol.lvs_name}/{lvol.lvol_bdev}"
     lvol.hostname = snode.hostname
     lvol.node_id = snode.get_id()
+    lvol.nodes = snap.lvol.nodes
     lvol.mode = 'read-write'
     lvol.cloned_from_snap = snapshot_id
     lvol.nqn = cluster.nqn + ":lvol:" + lvol.uuid
@@ -314,7 +315,6 @@ def clone(snapshot_id, clone_name, new_size=0):
     for iface in snode.data_nics:
         if iface.ip4_address:
             tr_type = iface.get_transport_type()
-            ret = rpc_client.transport_create(tr_type, cluster.qpair_count)
             logger.info("adding listener for %s on IP %s" % (subsystem_nqn, iface.ip4_address))
             ret = rpc_client.listeners_create(subsystem_nqn, tr_type, iface.ip4_address, "4420")
 
